#!perl -T

use strict;
use warnings;
use Test::More;
use Oceano::Convert;


# jeux de test
my %test = (
  # test : julian => date
  9       => [1999,1999,01,10,0,0,0],
  364     => [1999,1999,12,31,0,0,0],   #decembre
  374.5   => [1999,2000,01,10,12,0,0],  #plusieurs annees
  740.75  => [1999,2001,01,10,18,0,0],  #annee bissextile
  400.248 => [1999,2000,02,05,05,57,7], #heure
);
my %test2 = (
  # test : date_formatee => date,format
  "20060708130230"             => ["08/07/2006 13:02:30",0],
  "20060708130200"             => ["8/7/06 13:2",undef],
  "08/07/2006"                 => ["08-07-2006 13:02:30","%x"],
  "036"                        => ["05/02/2006","%j"],  
  "08/07/06"                   => ["8/7/06","%d/%m/%y"],
  "31 decembre 2006, 23:59:59" => ["31/12/06 23:59:59","%d %B %Y, %H:%M:%S"],
  "31 dec 1998, 23:59"         => ["31/12/98 23:59:59","%d %b %Y, %R"],
  "25/05/2007 20:11:31"        => ["25 Mai 2007 20:11:31","%x %X"],
);
my %test3 = (
  # test : date_formatee => date,format
  "05/25/2007"          => ["5/25/07 13:02:30","%x"],
  "October 25 2007"     => ["10/25/07","%B %d %Y"],
  "Oct 25 2007"         => ["10/25/07","%b %d %Y"],
  "05/25/2007 20:11:31" => ["May 25 2007 20:11:31","%x %X"],
);
my %test4 = (
  # test : date_formatee => date,format
  "25/05/2007 02:32:30" => ["25/05/07 13:02:30","%x %X"],
  "31/12/2007 13:29:59" => ["31/12/07 23:59:59","%x %X"],
  "31/12/2007 13:30:00" => ["01/01/08 00:00:00","%x %X"],
);

# nombre de tests prevus
plan tests => 13 + 7 * (scalar keys %test) +
                       (scalar keys %test2) +
                       (scalar keys %test3) +
                       (scalar keys %test4);

# tests date julienne
while (my($julian,$date) = each %test) {
  is(sprintf("%.3f",date2julian(@$date)), sprintf("%.3f",$julian),
    "julien ($julian)");

  my ($a,$m,$j,$h,$mn,$s) = julian2date($date->[0],$julian);
  is($a,  @$date[1], "annee ($julian)");
  is($m,  @$date[2], "mois ($julian)");
  is($j,  @$date[3], "jours ($julian)");
  is($h,  @$date[4], "heure ($julian)");
  is($mn, @$date[5], "minute ($julian)");
  is($s,  @$date[6], "seconde ($julian)");
}

# tests speciaux date julienne
is(sprintf("%.3f",date2julian(1999,2000,02,05)), sprintf("%.3f",400), 
  'julien param');
is(sprintf("%.3f",date2julian(1999,2000)), sprintf("%.3f",365), 
  'julien param');
is(sprintf("%.3f",date2julian(99,00,02,05,05,57,7)), sprintf("%.3f",400.248), 
  'julien YY');

# tests formatage date
diag(dateFormat("now","%x %X", 'date = now')); # date actuelle
diag(dateFormat(undef,"%x %X", 'date = undef'));
diag(dateFormat("%x %X", 'pas de date'));

dateInit("FR","GMT");
while (my($date,$param) = each %test2) {
  is(dateFormat(@$param[0],@$param[1]), $date);
}

dateInit(); # <=> dateInit("EN","GMT");
while (my($date,$param) = each %test3) {
  is(dateFormat(@$param[0],@$param[1]), $date);
}

dateInit("FR","ACDT"); # ACDT:GMT+10:30
while (my($date,$param) = each %test4) {
  is(dateFormat(@$param[0],@$param[1]), $date);
}

# tests position
is(positionDeci(121,8.10,"N"), 121.135,  'position decimale Nord');
is(positionDeci(121,8.10,"S"), -121.135, 'position decimale Sud');
is(positionDeci(121,8.10,"e"), 121.135,  'position decimale Est');
is(positionDeci(121,8.10,"w"), -121.135, 'position decimale Ouest');
is(positionDeci(positionSexa(121.135,"lat")),    121.135, 'position sexa lat');
is(positionDeci(positionSexa(-121.135,"LONG")), -121.135, 'position sexa long');

# tests formatage valeurs ROSCOP
is(roscopFormat("TEMP", 26.24),        "26.240",  'roscop');
is(roscopFormat("PSAL", 34.9242, ";"), ";34.924", 'roscop sep');
is(roscopFormat("PSAL", 99.999, "  "), "  1e36",  'roscop defaut');
is(roscopFormat("PSAL", 1e36),         "1e36",    'roscop exp');
