#!perl -T

use strict;
use warnings;
use Test::More tests => 7 + 8;
use Oceano::Seabird;

my ($sb1, $sb2, $sb3, $sb4);
my $con_file = "/home/decibel/nrannou/ege4042.con";

my %coefT = (
  'g'      =>  4.13773278e-003,
  'h'      =>  6.28255735e-004,
  'i'      =>  2.06477531e-005,
  'j'      =>  2.06792678e-006,
  'f0'     =>  1000.000,
);
my %coefP = (
  'C1'     => -4.527723e+004,
  'C2'     =>  5.305597e-001,
  'C3'     =>  1.261900e-002,
  'D1'     =>  4.109200e-002,
  'D2'     =>  0.000000e+000,
  'T1'     =>  2.995277e+001,
  'T2'     => -1.723925e-004,
  'T3'     =>  3.951640e-006,
  'T4'     =>  2.979390e-009,
  'T5'     =>  0.000000e+000,
  'AD590M' =>  1.128000e-002,
  'AD590B' => -8.758480e+000,
  'Slop'   =>  1.00000000,
  'Offset' => -0.40000,
);
my %coefC_a = (
  'a'      =>  2.07224157e-005,
  'b'      =>  5.21453841e-001,
  'c'      => -4.16659171e+000,
  'd'      => -8.18755096e-005,
  'm'      =>  4.1,
  'CPcor'  => -9.57000000e-008,
);
my %coefC = (
  'g'      => -4.17370578e+000,
  'h'      =>  5.22749729e-001,
  'i'      => -1.44204757e-004,
  'j'      =>  3.38621541e-005,
  'CTcor'  =>  3.2500e-006,
  'CPcor'  => -9.57000000e-008,
);
my %coefO = (
  'Soc'    =>  4.3170e-001,
  'Boc'    =>  0.0,
  'Voffset'=> -0.5939,
  'TCor'   =>  0.001000,
  'PCor'   =>  1.35e-004,
);


# Initialisation
$sb1 = Seabird->new_h(\%coefT, \%coefP, \%coefC, \%coefO);
$sb2 = Seabird->new_h(\%coefT, \%coefP, \%coefC_a, \%coefO);
$sb3 = Seabird->new($con_file);
$sb4 = Seabird->new($con_file, 2);

ok(defined $sb1, '$sb1 defini');
ok(defined $sb2, '$sb2 defini');
ok(defined $sb3, '$sb3 defini');
ok(defined $sb4, '$sb4 defini');
ok($sb1->isa('Seabird'), 'classe $sb1');
ok($sb2->isa('Seabird'), 'classe $sb2');
ok($sb3->isa('Seabird'), 'classe $sb3');
ok($sb4->isa('Seabird'), 'classe $sb4');

=pod
# H:hashage, F:fichier, F2:fichier secondaire
# g:coefs ghij, a:coefs abcd
# Temperature
is(sprintf("%.4f",$sb1->temp(3769.251)), '26.6428', 'Temp H_g');
is(sprintf("%.4f",$sb3->temp(3769.251)), '26.6428', 'Temp F');
is(sprintf("%.4f",$sb4->temp(3747.199)), '26.6467', 'Temp F2');

# Pression
is(sprintf("%.3f",$sb1->pres(33409.468, 26.6428)), '30.000', 'Pres H');
is(sprintf("%.3f",$sb3->pres(33409.468, 26.6428)), '30.000', 'Pres F');

# Conductivite
is(sprintf("%.6f",$sb1->cond(10613.864, 26.6428, 30.000)), '5.496892', "Cond H_g");
is(sprintf("%.6f",$sb2->cond(10613.864, 26.6428, 30.000)), '5.496892', "Cond H_a");
is(sprintf("%.6f",$sb3->cond(10613.864, 26.6428, 30.000)), '5.496892', "Cond F");
is(sprintf("%.6f",$sb4->cond(10834.546, 26.6467, 30.000)), '5.496970', "Cond F2");

# Oxygene
is($sb1->ox(3.0172, 26.6428, 30.000, 35.1166), '0', "Ox H");
is($sb3->ox(3.0172, 26.6428, 30.000, 35.1166), '0', "Ox F");
is($sb4->ox(3.3907, 26.6467, 30.000, 35.1142), '0', "Ox F2");
=cut


# tests fonction roscop
is(Seabird->roscop("t090C"), "TE01");
is(Seabird->roscop("T190C"), "TE02");
is(Seabird->roscop("SAL00"), "PSA1");
is(Seabird->roscop("sal11"), "PSA2");
is(Seabird->roscop("c_S/m"), "CNDC");
is(Seabird->roscop("OXML/L",0), "DO11");
is(Seabird->roscop("OXML/L",1), "DOX1");

